@@ -42,13 +42,7 @@ class Alarmdotcom:
     }
 
     def __init__(
-        self,
-        username,
-        password,
-        websession,
-        forcebypass=False,
-        noentrydelay=False,
-        silentarming=False,
+        self, username, password, websession, forcebypass, noentrydelay, silentarming,
     ):
         """
         Use aiohttp to make a request to alarm.com
@@ -235,10 +229,16 @@ class Alarmdotcom:
             json = {"statePollOnly": False}
         else:
             json = {
-                "forceBypass": forcebypass,
-                "noEntryDelay": noentrydelay,
-                "silentArming": silentarming,
                 "statePollOnly": False,
+                **{
+                    key: value
+                    for key, value in {
+                        "forceBypass": forcebypass,
+                        "noEntryDelay": noentrydelay,
+                        "silentArming": silentarming,
+                    }.items()
+                    if value is True
+                },
             }
         try:
             async with self._websession.post(
@@ -253,8 +253,16 @@ class Alarmdotcom:
                 if resp.status == 200:
                     # Update alarm.com status after calling state change.
                     await self.async_update()
-                elif resp.status >= 400:
+                if resp.status == 403:
                     raise aiohttp.ClientError
+                elif resp.status >= 400:
+                    _LOGGER.error("%s failed with HTTP code %s", event, resp.status)
+                    _LOGGER.error(
+                        "Arming parameters: force_bypass = %s, no_entry_delay = %s, silent_arming = %s",
+                        forcebypass,
+                        noentrydelay,
+                        silentarming,
+                    )
         except aiohttp.ClientError:
             # May have been logged out, try again
             _LOGGER.error("Error executing %s, logging in and trying again...", event)
